'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _rollupPluginBabelHelpers = require('./_virtual/_rollupPluginBabelHelpers.cjs');
var umi = require('@metaplex-foundation/umi');

/** @category Errors */
class DataViewSerializerError extends umi.UmiError {
  constructor(message, cause) {
    super(message, 'plugin', 'DataView Serializer', cause);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'DataViewSerializerError');
  }
}
class OperationNotSupportedError extends DataViewSerializerError {
  constructor(operation) {
    super(`The operation [${operation}] is ` + `not supported by the DataView Serializer.`);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'OperationNotSupportedError');
  }
}
class DeserializingEmptyBufferError extends DataViewSerializerError {
  constructor(serializer) {
    super(`Serializer [${serializer}] cannot deserialize empty buffers.`);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'DeserializingEmptyBufferError');
  }
}
class NotEnoughBytesError extends DataViewSerializerError {
  constructor(serializer, expected, actual) {
    super(`Serializer [${serializer}] expected ${expected} bytes, got ${actual}.`);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'NotEnoughBytesError');
  }
}
class NumberOutOfRangeError extends DataViewSerializerError {
  constructor(serializer, min, max, actual) {
    super(`Serializer [${serializer}] expected number to be between ${min} and ${max}, got ${actual}.`);
    _rollupPluginBabelHelpers.defineProperty(this, "name", 'NumberOutOfRangeError');
  }
}

exports.DataViewSerializerError = DataViewSerializerError;
exports.DeserializingEmptyBufferError = DeserializingEmptyBufferError;
exports.NotEnoughBytesError = NotEnoughBytesError;
exports.NumberOutOfRangeError = NumberOutOfRangeError;
exports.OperationNotSupportedError = OperationNotSupportedError;
//# sourceMappingURL=errors.cjs.map
